<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class UnitKerja extends Model
{
    use HasFactory, SoftDeletes;

    protected $fillable = [
        'nama', 'induk_opd_id', 'tipe'
    ];

    public function DokterSpesialis(){
        return $this->hasOne(DokterSpesialis::class);
    }
    public function Dokter(){
        return $this->hasOne(Dokter::class);
    }
    public function DokterGigi(){
        return $this->hasOne(DokterGigi::class);
    }
    public function DokterGigiSpesialis(){
        return $this->hasOne(DokterGigiSpesialis::class);
    }
    public function Perawat(){
        return $this->hasOne(Perawat::class);
    }
    public function Bidan(){
        return $this->hasOne(Bidan::class);
    }
    public function TenagaKesehatanMasyarakat(){
        return $this->hasOne(TenagaKesehatanMasyarakat::class);
    }
    public function TenagaKesehatanLingkungan(){
        return $this->hasOne(TenagaKesehatanLingkungan::class);
    }
    public function TenagaGizi(){
        return $this->hasOne(TenagaGizi::class);
    }
    public function AhliLabMedik(){
        return $this->hasOne(AhliLabMedik::class);
    }
    public function TenagaTeknikBiomedik(){
        return $this->hasOne(TenagaTeknikBiomedik::class);
    }
    public function TenagaTeknikFarmasi(){
        return $this->hasOne(TenagaTeknisFarmasi::class);
    }
    public function TerapiFisik(){
        return $this->hasOne(TerapiFisik::class);
    }
    public function KeteknisanMedik(){
        return $this->hasOne(KeteknisanMedik::class);
    }
    public function Apoteker(){
        return $this->hasOne(Apoteker::class);
    }
    public function PejabatStruktural(){
        return $this->hasOne(PejabatStruktural::class);
    }
    public function TenagaPendidik(){
        return $this->hasOne(TenagaPendidik::class);
    }
    public function Manajemen(){
        return $this->hasOne(Manajemen::class);
    }
    public function Posyandu(){
        return $this->hasOne(Posyandu::class);
    }
    public function Desa(){
        return $this->hasMany(Desa::class);
    }
    public function k1($year = null){
        $desa = $this->Desa()->get();
        $k1 = 0;
        foreach ($desa as $key => $value) {
            # code...
            $k1 += $value->filterDesa($year)?$value->filterDesa($year)->k1:0;
        }
        return $k1;
    }
    public function k4($year = null){
        $desa = $this->Desa()->get();
        $k4 = 0;
        foreach ($desa as $key => $value) {
            # code...
            $k4 += $value->filterDesa($year)?$value->filterDesa($year)->k4:0;
        }
        return $k4;
    }
    public function k6($year = null){
        $desa = $this->Desa()->get();
        $k6 = 0;
        foreach ($desa as $key => $value) {
            # code...
            $k6 += $value->filterDesa($year)?$value->filterDesa($year)->k6:0;
        }
        return $k6;
    }
    public function fasyankes($year = null){
        $desa = $this->Desa()->get();
        $fasyankes = 0;
        foreach ($desa as $key => $value) {
            # code...
            $fasyankes += $value->filterDesa($year)?$value->filterDesa($year)->fasyankes:0;
        }
        return $fasyankes;
    }
    public function kf1($year = null){
        $desa = $this->Desa()->get();
        $kf1 = 0;
        foreach ($desa as $key => $value) {
            # code...
            $kf1 += $value->filterDesa($year)?$value->filterDesa($year)->kf1:0;
        }
        return $kf1;
    }
    public function kf_lengkap($year = null){
        $desa = $this->Desa()->get();
        $kf_lengkap = 0;
        foreach ($desa as $key => $value) {
            # code...
            $kf_lengkap += $value->filterDesa($year)?$value->filterDesa($year)->kf_lengkap:0;
        }
        return $kf_lengkap;
    }
    public function vita($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterDesa($year)?$value->filterDesa($year)->vita:0;
        }
        return $vita;
    }
    public function lahir_hidup_L($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKelahiran($year)?$value->filterKelahiran($year)->lahir_hidup_L:0;
        }
        return $vita;
    }
    public function lahir_hidup_P($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKelahiran($year)?$value->filterKelahiran($year)->lahir_hidup_P:0;
        }
        return $vita;
    }
    public function kn1_L($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterNeonatal($year)?$value->filterNeonatal($year)->kn1_L:0;
        }
        return $vita;
    }
    public function kn1_P($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterNeonatal($year)?$value->filterNeonatal($year)->kn1_P:0;
        }
        return $vita;
    }
    public function kn_lengkap_L($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterNeonatal($year)?$value->filterNeonatal($year)->kn_lengkap_L:0;
        }
        return $vita;
    }
    public function kn_lengkap_P($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterNeonatal($year)?$value->filterNeonatal($year)->kn_lengkap_P:0;
        }
        return $vita;
    }
    public function hipo_L($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterNeonatal($year)?$value->filterNeonatal($year)->hipo_L:0;
        }
        return $vita;
    }
    public function hipo_P($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterNeonatal($year)?$value->filterNeonatal($year)->hipo_P:0;
        }
        return $vita;
    }
    public function balita_0_59($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKesehatanBalita($year)?$value->filterKesehatanBalita($year)->balita_0_59:0;
        }
        return $vita;
    }
    public function balita_12_59($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKesehatanBalita($year)?$value->filterKesehatanBalita($year)->balita_12_59:0;
        }
        return $vita;
    }
    public function balita_kia($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKesehatanBalita($year)?$value->filterKesehatanBalita($year)->balita_kia:0;
        }
        return $vita;
    }
    public function balita_dipantau($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKesehatanBalita($year)?$value->filterKesehatanBalita($year)->balita_kia:0;
        }
        return $vita;
    }
    public function balita_sdidtk($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKesehatanBalita($year)?$value->filterKesehatanBalita($year)->balita_sdidtk:0;
        }
        return $vita;
    }
    public function balita_mtbs($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterKesehatanBalita($year)?$value->filterKesehatanBalita($year)->balita_mtbs:0;
        }
        return $vita;
    }
    public function jumlah_kelas_1($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_kelas_1:0;
        }
        return $vita;
    }
    public function pelayanan_kelas_1($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_kelas_1:0;
        }
        return $vita;
    }
    public function jumlah_kelas_7($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_kelas_7:0;
        }
        return $vita;
    }
    public function pelayanan_kelas_7($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_kelas_7:0;
        }
        return $vita;
    }
    public function jumlah_kelas_10($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_kelas_10:0;
        }
        return $vita;
    }
    public function pelayanan_kelas_10($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_kelas_10:0;
        }
        return $vita;
    }
    public function jumlah_usia_dasar($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_usia_dasar:0;
        }
        return $vita;
    }
    public function pelayanan_usia_dasar($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_usia_dasar:0;
        }
        return $vita;
    }
    public function jumlah_sd($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_sd:0;
        }
        return $vita;
    }
    public function pelayanan_sd($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_sd:0;
        }
        return $vita;
    }
    public function jumlah_smp($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_smp:0;
        }
        return $vita;
    }
    public function pelayanan_smp($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_smp:0;
        }
        return $vita;
    }
    public function jumlah_sma($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->jumlah_sma:0;
        }
        return $vita;
    }
    public function pelayanan_sma($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterPesertaDidik($year)?$value->filterPesertaDidik($year)->pelayanan_sma:0;
        }
        return $vita;
    }
    public function jumlah_ibu_hamil($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterDesa($year)?$value->filterDesa($year)->jumlah_ibu_hamil:0;
        }
        return $vita;
    }
    public function lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterDesa($year)){
                $status = $value->filterDesa($year)->status;
            }
        }
        return $status;
    }
    public function kelahiran_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterKelahiran($year)){
                $status = $value->filterKelahiran($year)->status;
            }
        }
        return $status;
    }
    public function neonatal_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterNeonatal($year)){
                $status = $value->filterNeonatal($year)->status;
            }
        }
        return $status;
    }
    public function kesehatan_balita_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterKesehatanBalita($year)){
                $status = $value->filterKesehatanBalita($year)->status;
            }
        }
        return $status;
    }
    public function peserta_didik_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterPesertaDidik($year)){
                $status = $value->filterPesertaDidik($year)->status;
            }
        }
        return $status;
    }
    public function pelayanan_produktif_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterPelayananProduktif($year)){
                $status = $value->filterPelayananProduktif($year)->status;
            }
        }
        return $status;
    }
    public function pelayanan_lansia_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterPelayananLansia($year)){
                $status = $value->filterPelayananLansia($year)->status;
            }
        }
        return $status;
    }
    public function tuberkulosis_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterTuberkulosis($year)){
                $status = $value->filterTuberkulosis($year)->status;
            }
        }
        return $status;
    }
    public function hipertensi_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterHipertensi($year)){
                $status = $value->filterHipertensi($year)->status;
            }
        }
        return $status;
    }
    public function diabetes_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterDiabetes($year)){
                $status = $value->filterDiabetes($year)->status;
            }
        }
        return $status;
    }
    public function kunjungan_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterKunjungan($year)){
                $status = $value->filterKunjungan($year)->status;
            }
        }
        return $status;
    }
    public function odgj_lock_get($year = null){
        $desa = $this->Desa()->get();
        $status = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterOdgj($year)){
                $status = $value->filterOdgj($year)->status;
            }
        }
        return $status;
    }
    public function lock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterDesa($year)){
                    $value->filterDesa($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterDesa($year)){
                    $value->filterDesa($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function KelahiranLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterKelahiran($year)){
                    $value->filterKelahiran($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterKelahiran($year)){
                    $value->filterKelahiran($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function NeonatalLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterNeonatal($year)){
                    $value->filterNeonatal($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterNeonatal($year)){
                    $value->filterNeonatal($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function KesehatanBalitaLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterKesehatanBalita($year)){
                    $value->filterKesehatanBalita($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterKesehatanBalita($year)){
                    $value->filterKesehatanBalita($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function PesertaDidikLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterPesertaDidik($year)){
                    $value->filterPesertaDidik($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterPesertaDidik($year)){
                    $value->filterPesertaDidik($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function PelayananProduktifLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterPelayananProduktif($year)){
                    $value->filterPelayananProduktif($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterPelayananProduktif($year)){
                    $value->filterPelayananProduktif($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function PelayananLansiaLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterPelayananLansia($year)){
                    $value->filterPelayananLansia($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterPelayananLansia($year)){
                    $value->filterPelayananLansia($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function TuberkulosisLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterTuberkulosis($year)){
                    $value->filterTuberkulosis($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterTuberkulosis($year)){
                    $value->filterTuberkulosis($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function HipertensiLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterHipertensi($year)){
                    $value->filterHipertensi($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterHipertensi($year)){
                    $value->filterHipertensi($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function DiabetesLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterDiabetes($year)){
                    $value->filterDiabetes($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterDiabetes($year)){
                    $value->filterDiabetes($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function KunjunganLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterKunjungan($year)){
                    $value->filterKunjungan($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterKunjungan($year)){
                    $value->filterKunjungan($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function OdgjLock($year = null, $status){
        $desa = $this->Desa()->get();
        foreach ($desa as $key => $value) {
            # code...
            if($status == 1){
                if($value->filterOdgj($year)){
                    $value->filterOdgj($year)->update([
                        'status' => 1,
                    ]);
                } else {
                    continue;
                }
            } else {
                if($value->filterOdgj($year)){
                    $value->filterOdgj($year)->update([
                        'status' => 0,
                    ]);
                } else {
                    continue;
                }
            }
        }
        return 1;
    }
    public function jumlah_ibu_bersalin($year = null){
        $desa = $this->Desa()->get();
        $vita = 0;
        foreach ($desa as $key => $value) {
            # code...
            $vita += $value->filterDesa($year)?$value->filterDesa($year)->jumlah_ibu_bersalin:0;
        }
        return $vita;
    }

    public function kelahiran_per_desa($year = null){
        $desa = $this->Desa()->get();
        $lahir_hidup_L = 0;
        $lahir_mati_L = 0;
        $lahir_hidup_P = 0;
        $lahir_mati_P = 0;
        $lahir_hidup_LP = 0;
        $lahir_mati_LP = 0;
        $lahir_hidup_mati_LP = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterKelahiran($year)){
                $lahir_hidup_L += $value->filterKelahiran($year)->lahir_hidup_L;
                $lahir_mati_L += $value->filterKelahiran($year)->lahir_mati_L;
                $lahir_hidup_P += $value->filterKelahiran($year)->lahir_hidup_P;
                $lahir_mati_P += $value->filterKelahiran($year)->lahir_mati_P;
                $lahir_hidup_LP += $value->filterKelahiran($year)->lahir_hidup_L + $value->filterKelahiran($year)->lahir_hidup_P;
                $lahir_mati_LP += $value->filterKelahiran($year)->lahir_mati_L + $value->filterKelahiran($year)->lahir_mati_P;
                $lahir_hidup_mati_LP += $value->filterKelahiran($year)->lahir_mati_L + $value->filterKelahiran($year)->lahir_mati_P + $value->filterKelahiran($year)->lahir_hidup_L + $value->filterKelahiran($year)->lahir_hidup_P;
    
            }
        }
        return compact('lahir_hidup_L', 'lahir_mati_L', 'lahir_hidup_P', 'lahir_mati_P', 'lahir_hidup_LP', 'lahir_mati_LP', 'lahir_hidup_mati_LP');
    }
    public function neonatal_per_desa($year = null){
        $desa = $this->Desa()->get();
        $kn1_L = 0;
        $kn1_P = 0;
        $jumlah_kn1_LP = 0;
        $persen_kn1_LP = 0;
        $kn_lengkap_P = 0;
        $kn_lengkap_L = 0;
        $jumlah_kn_lengkap_LP = 0;
        $persen_kn_lengkap_LP = 0; 
        $hipo_L = 0;
        $hipo_P = 0;
        $jumlah_hipo_LP = 0;
        $persen_hipo_LP = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterNeonatal($year)){
                $kn1_L += $value->filterNeonatal($year)->kn1_L;
            $kn1_P += $value->filterNeonatal($year)->kn1_P;
            $kn_lengkap_L += $value->filterNeonatal($year)->kn_lengkap_L;
            $kn_lengkap_P += $value->filterNeonatal($year)->kn_lengkap_P;
            $hipo_L += $value->filterNeonatal($year)->hipo_L;
            $hipo_P += $value->filterNeonatal($year)->hipo_L;
            }
            

        }
        return compact('kn1_L', 'kn1_P', 'kn_lengkap_L', 'kn_lengkap_P', 'hipo_L', 'hipo_P');
    }
    public function kesehatan_balita_per_desa($year = null){
        $desa = $this->Desa()->get();
        $balita_0_59 = 0;
        $balita_12_59 = 0;
        $balita_kia = 0;
        $balita_dipantau = 0;
        $balita_sdidtk = 0;
        $balita_mtbs = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterKesehatanBalita($year)){
                $balita_0_59 += $value->filterKesehatanBalita($year)->balita_0_59;
                $balita_12_59 += $value->filterKesehatanBalita($year)->balita_12_59;
                $balita_kia += $value->filterKesehatanBalita($year)->balita_kia;
                $balita_dipantau += $value->filterKesehatanBalita($year)->balita_dipantau;
                $balita_sdidtk += $value->filterKesehatanBalita($year)->balita_sdidtk;
                $balita_mtbs += $value->filterKesehatanBalita($year)->balita_mtbs;
            }
            

        }
        return compact('balita_0_59', 'balita_12_59', 'balita_kia', 'balita_dipantau', 'balita_sdidtk', 'balita_mtbs');
    }
    public function peserta_didik_per_desa($year = null){
        $desa = $this->Desa()->get();
        $jumlah_kelas_1 = 0;
        $pelayanan_kelas_1 = 0;
        $jumlah_kelas_7 = 0;
        $pelayanan_kelas_7 = 0;
        $jumlah_kelas_10 = 0;
        $pelayanan_kelas_10 = 0;
        $jumlah_usia_dasar = 0;
        $pelayanan_usia_dasar = 0;
        $jumlah_sd = 0;
        $pelayanan_sd = 0;
        $jumlah_smp = 0;
        $pelayanan_smp = 0;
        $jumlah_sma = 0;
        $pelayanan_sma = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterPesertaDidik($year)){
            $jumlah_kelas_1 += $value->filterPesertaDidik($year)->jumlah_kelas_1;
            $pelayanan_kelas_1 += $value->filterPesertaDidik($year)->pelayanan_kelas_1;
            $jumlah_kelas_7 += $value->filterPesertaDidik($year)->jumlah_kelas_7;
            $pelayanan_kelas_7 += $value->filterPesertaDidik($year)->pelayanan_kelas_7;
            $jumlah_kelas_10 += $value->filterPesertaDidik($year)->jumlah_kelas_10;
            $pelayanan_kelas_10 += $value->filterPesertaDidik($year)->pelayanan_kelas_10;
            $jumlah_usia_dasar += $value->filterPesertaDidik($year)->jumlah_usia_dasar;
            $pelayanan_usia_dasar += $value->filterPesertaDidik($year)->pelayanan_usia_dasar;
            $jumlah_sd += $value->filterPesertaDidik($year)->jumlah_sd;
            $pelayanan_sd += $value->filterPesertaDidik($year)->pelayanan_sd;
            $jumlah_smp += $value->filterPesertaDidik($year)->jumlah_smp;
            $pelayanan_smp += $value->filterPesertaDidik($year)->pelayanan_smp;
            $jumlah_sma += $value->filterPesertaDidik($year)->jumlah_sma;
            $pelayanan_sma += $value->filterPesertaDidik($year)->pelayanan_sma;

            }
        }
        return compact('jumlah_kelas_1', 'pelayanan_kelas_1', 'jumlah_kelas_7', 'pelayanan_kelas_7', 'jumlah_kelas_10', 'pelayanan_kelas_10', 'jumlah_usia_dasar', 'pelayanan_usia_dasar', 'jumlah_sd', 'pelayanan_sd', 'jumlah_smp', 'pelayanan_smp', 'jumlah_sma', 'pelayanan_sma');
    }
    public function pelayanan_produktif_per_desa($year = null){
        $desa = $this->Desa()->get();
        $jumlah_L = 0;
        $jumlah_P = 0;
        $standar_L = 0;
        $standar_P = 0;
        $risiko_L = 0;
        $risiko_P = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterPelayananProduktif($year)){
                $jumlah_L += $value->filterPelayananProduktif($year)->jumlah_L;
                $jumlah_P += $value->filterPelayananProduktif($year)->jumlah_P;
                $standar_L += $value->filterPelayananProduktif($year)->standar_L;
                $standar_P += $value->filterPelayananProduktif($year)->standar_P;
                $risiko_L += $value->filterPelayananProduktif($year)->risiko_L;
                $risiko_P += $value->filterPelayananProduktif($year)->risiko_P;
            }

        }
        return compact('jumlah_L', 'jumlah_P', 'standar_L', 'standar_P', 'risiko_L', 'risiko_P');
    }
    public function pelayanan_lansia_per_desa($year = null){
        $desa = $this->Desa()->get();
        $jumlah_L = 0;
        $jumlah_P = 0;
        $standar_L = 0;
        $standar_P = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterPelayananLansia($year)){
                $jumlah_L += $value->filterPelayananLansia($year)->jumlah_L;
                $jumlah_P += $value->filterPelayananLansia($year)->jumlah_P;
                $standar_L += $value->filterPelayananLansia($year)->standar_L;
                $standar_P += $value->filterPelayananLansia($year)->standar_P;
            }
        }
        return compact('jumlah_L', 'jumlah_P', 'standar_L', 'standar_P');
    }
    public function tuberkulosis_per_desa($year = null){
        $desa = $this->Desa()->get();
        $kasus_L = 0;
        $kasus_P = 0;
        $terduga_kasus = 0;
        $kasus_LP = 0;
        $kasus_anak = 0;
        
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterTuberkulosis($year)){
                $kasus_L += $value->filterTuberkulosis($year)->kasus_L;
                $kasus_P += $value->filterTuberkulosis($year)->kasus_P;
                $kasus_LP += $value->filterTuberkulosis($year)->kasus_LP;
                $terduga_kasus += $value->filterTuberkulosis($year)->terduga_kasus;
                $kasus_anak += $value->filterTuberkulosis($year)->kasus_anak;
            }
        }
        return compact('kasus_L', 'kasus_P', 'kasus_LP', 'terduga_kasus', 'kasus_anak');
    }
    public function hipertensi_per_desa($year = null){
        $desa = $this->Desa()->get();
        $jumlah_L = 0;
        $jumlah_P = 0;
        $pelayanan_L = 0;
        $pelayanan_P = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterHipertensi($year)){
                $jumlah_L += $value->filterHipertensi($year)->jumlah_L;
            $jumlah_P += $value->filterHipertensi($year)->jumlah_P;
            $pelayanan_L += $value->filterHipertensi($year)->pelayanan_L;
            $pelayanan_P += $value->filterHipertensi($year)->pelayanan_P;
            }
        }
        return compact('jumlah_L', 'jumlah_P', 'pelayanan_L', 'pelayanan_P');
    }
    public function diabetes_per_desa($year = null){
        $desa = $this->Desa()->get();
        $jumlah = 0;
        $pelayanan = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterDiabetes($year)){
                $jumlah += $value->filterDiabetes($year)->jumlah;
                $pelayanan += $value->filterDiabetes($year)->pelayanan;
            }
        }
        return compact('jumlah', 'pelayanan');
    }
    public function kunjungan_per_desa($year = null){
        $desa = $this->Desa()->get();
        $jalan_L = 0;
        $jalan_P = 0;
        $inap_L = 0;
        $inap_P = 0;
        $jiwa_L = 0;
        $jiwa_P = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterKunjungan($year)){
                $jalan_L += $value->filterKunjungan($year)->jalan_L;
            $jalan_P += $value->filterKunjungan($year)->jalan_P;
            $inap_P += $value->filterKunjungan($year)->inap_P;
            $inap_L += $value->filterKunjungan($year)->inap_L;
            $jiwa_L += $value->filterKunjungan($year)->jiwa_L;
            $jiwa_P += $value->filterKunjungan($year)->jiwa_P;
            }
        }
        return compact('jalan_L', 'jalan_P', 'inap_L', 'inap_P', 'jiwa_L', 'jiwa_P',);
    }
    public function odgj_per_desa($year = null){
        $desa = $this->Desa()->get();
        $skizo_0 = 0;
        $skizo_15 = 0;
        $skizo_60 = 0;
        $psiko_0 = 0;
        $psiko_15 = 0;
        $psiko_60 = 0;
        $sasaran = 0;
        foreach ($desa as $key => $value) {
            # code...
            if($value->filterOdgj($year)){
                $skizo_0 += $value->filterOdgj($year)->skizo_0;
                $skizo_15 += $value->filterOdgj($year)->skizo_15;
                $skizo_60 += $value->filterOdgj($year)->skizo_60;
                $psiko_0 += $value->filterOdgj($year)->psiko_0;
                $psiko_15 += $value->filterOdgj($year)->psiko_15;
                $psiko_60 += $value->filterOdgj($year)->psiko_60;
                $sasaran += $value->filterOdgj($year)->sasaran;
            }
        }
        return compact('skizo_0', 'skizo_15', 'skizo_60', 'psiko_0', 'psiko_15', 'psiko_60', 'sasaran');
    }
}
